==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Manjka ključ za obnovitev",
    "Please repeat the recovery key password" : "Ponovite vpis ključa za obnovitev",
    "Repeated recovery key password does not match the provided recovery key password" : "Ponovljen vpis ključa za obnovitev ni enak prvemu vpisu tega ključa",
    "Recovery key successfully enabled" : "Ključ za obnovitev gesla je uspešno nastavljen",
    "Could not enable recovery key. Please check your recovery key password!" : "Ključa za obnovitev gesla ni mogoče nastaviti. Preverite geslo ključa!",
    "Recovery key successfully disabled" : "Ključ za obnovitev gesla je uspešno onemogočen",
    "Could not disable recovery key. Please check your recovery key password!" : "Ključa za obnovitev gesla ni mogoče onemogočiti. Preverite ključ!",
    "Missing parameters" : "Manjkajoči parametri:",
    "Please provide the old recovery password" : "Vpišite star ključ za obnovitev",
    "Please provide a new recovery password" : "Vpišite nov ključ za obnovitev",
    "Please repeat the new recovery password" : "Ponovno vpišite nov ključ za obnovitev",
    "Password successfully changed." : "Geslo je uspešno spremenjeno.",
    "Could not change the password. Maybe the old password was not correct." : "Gesla ni mogoče spremeniti. Morda vnos starega gesla ni pravilen.",
    "Recovery Key disabled" : "Ključ za obnovitev gesla je onemogočen.",
    "Recovery Key enabled" : "Ključ za obnovitev gesla je omogočen.",
    "Could not enable the recovery key, please try again or contact your administrator" : "Ni mogoče omogočiti obnovitvenega ključa. Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Could not update the private key password." : "Ni mogoče posodobiti gesla zasebnega ključa.",
    "The old password was not correct, please try again." : "Staro geslo ni vpisano pravilno. Poskusite znova.",
    "The current log-in password was not correct, please try again." : "Trenutno geslo za prijavo ni vpisano pravilno. Poskusite znova.",
    "Private key password successfully updated." : "Zasebni ključ za geslo je uspešno posodobljen.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega. Zaženite ukaz 'occ encryption:migrate' ali pa stopite v stik s skrbnikom sistema.",
    "Bad Signature" : "Neustrezen podpis",
    "Missing Signature" : "Manjkajoč podpis",
    "one-time password for server-side-encryption" : "enkratno geslo za šifriranje na strani strežnika",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Te datoteke ni mogoče šifrirati, ker je to najverjetneje datoteka v souporabi. Prosite lastnika datoteke, da jo da ponovno v souporabo.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Te datoteke ni mogoče brati, ker je to najverjetneje datoteka v souporabi. Prosite lastnika datoteke, da jo da ponovno v souporabo.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Pozdravljeni,\n\nadministrator je vklopil šifriranje na strežniku. Vaše datoteke bodo šifrirane z geslom '%s'.\n\nProsimo, prijavite se na spletno stran, pojdite na sekcijo 'basic encryption module' vaših osebnih nastavitev in posodobite vaše šifrirno geslo z vnosom tega gesla v polje 'old log-in password' in vašega trenutnega prijavnega gesla.\n\n",
    "The share will expire on %s." : "Povezava souporabe bo potekla %s.",
    "Cheers!" : "Lep pozdrav!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Pozdravljeni,<br><br> administrator je vklopil šifriranje na strežniku. Vaše datoteke bodo šifrirane z geslom <strong>%s</strong>.<br><br> Prosimo, prijavite se na spletno stran, pojdite na sekcijo 'basic encryption module' vaših osebnih nastavitev in posodobite vaše šifrirno geslo z vnosom tega gesla v polje 'old log-in password' in vašega trenutnega prijavnega gesla.<br><br>",
    "Encrypt the home storage" : "Šifriraj domačo shrambo",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Izbrana možnost omogoči šifriranje vseh datotek, shranjenih v glavni shrambi, sicer so šifrirane le datoteke v zunanjih shrambah.",
    "Enable recovery key" : "Omogoči obnovitev gesla",
    "Disable recovery key" : "Onemogoči obnovitev gesla",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Obnovitveni ključ je dodatni šifrirni ključ, ki se uporablja pri šifriranju datotek. Omogoča obnovitev uporabnikovih datotek, če uporabnih pozabi svoje geslo za dostop.",
    "Recovery key password" : "Ključ za obnovitev gesla",
    "Repeat recovery key password" : "Ponovi ključ za obnovitev gesla",
    "Change recovery key password:" : "Spremeni ključ za obnovitev gesla:",
    "Old recovery key password" : "Stari ključ za obnovitev gesla",
    "New recovery key password" : "Novi ključ za obnovitev gesla",
    "Repeat new recovery key password" : "Ponovi novi ključ za obnovitev gesla",
    "Change Password" : "Spremeni geslo",
    "Your private key password no longer matches your log-in password." : "Zasebno geslo ni več skladno s prijavnim geslom.",
    "Set your old private key password to your current log-in password:" : "Nastavite star zasebni ključ na trenutno prijavno geslo:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Če ste pozabili svoje geslo, lahko vaše datoteke obnovi le skrbnik sistema.",
    "Old log-in password" : "Staro geslo",
    "Current log-in password" : "Trenutno geslo",
    "Update Private Key Password" : "Posodobi zasebni ključ",
    "Enable password recovery:" : "Omogoči obnovitev gesla:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Nastavitev te možnosti omogoča ponovno pridobitev dostopa do šifriranih datotek, v primeru, da boste geslo pozabili.",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Program za šifriranje je omogočen, vendar ni začet. Odjavite se in nato ponovno prijavite."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Manjka ključ za obnovitev",
    "Please repeat the recovery key password" : "Ponovite vpis ključa za obnovitev",
    "Repeated recovery key password does not match the provided recovery key password" : "Ponovljen vpis ključa za obnovitev ni enak prvemu vpisu tega ključa",
    "Recovery key successfully enabled" : "Ključ za obnovitev gesla je uspešno nastavljen",
    "Could not enable recovery key. Please check your recovery key password!" : "Ključa za obnovitev gesla ni mogoče nastaviti. Preverite geslo ključa!",
    "Recovery key successfully disabled" : "Ključ za obnovitev gesla je uspešno onemogočen",
    "Could not disable recovery key. Please check your recovery key password!" : "Ključa za obnovitev gesla ni mogoče onemogočiti. Preverite ključ!",
    "Missing parameters" : "Manjkajoči parametri:",
    "Please provide the old recovery password" : "Vpišite star ključ za obnovitev",
    "Please provide a new recovery password" : "Vpišite nov ključ za obnovitev",
    "Please repeat the new recovery password" : "Ponovno vpišite nov ključ za obnovitev",
    "Password successfully changed." : "Geslo je uspešno spremenjeno.",
    "Could not change the password. Maybe the old password was not correct." : "Gesla ni mogoče spremeniti. Morda vnos starega gesla ni pravilen.",
    "Recovery Key disabled" : "Ključ za obnovitev gesla je onemogočen.",
    "Recovery Key enabled" : "Ključ za obnovitev gesla je omogočen.",
    "Could not enable the recovery key, please try again or contact your administrator" : "Ni mogoče omogočiti obnovitvenega ključa. Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Could not update the private key password." : "Ni mogoče posodobiti gesla zasebnega ključa.",
    "The old password was not correct, please try again." : "Staro geslo ni vpisano pravilno. Poskusite znova.",
    "The current log-in password was not correct, please try again." : "Trenutno geslo za prijavo ni vpisano pravilno. Poskusite znova.",
    "Private key password successfully updated." : "Zasebni ključ za geslo je uspešno posodobljen.",
    "Bad Signature" : "Neustrezen podpis",
    "Missing Signature" : "Manjkajoč podpis",
    "one-time password for server-side-encryption" : "enkratno geslo za šifriranje na strani strežnika",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Te datoteke ni mogoče šifrirati, ker je to najverjetneje datoteka v souporabi. Prosite lastnika datoteke, da jo da ponovno v souporabo.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Te datoteke ni mogoče brati, ker je to najverjetneje datoteka v souporabi. Prosite lastnika datoteke, da jo da ponovno v souporabo.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Pozdravljeni,\n\nadministrator je vklopil šifriranje na strežniku. Vaše datoteke bodo šifrirane z geslom '%s'.\n\nProsimo, prijavite se na spletno stran, pojdite na sekcijo 'basic encryption module' vaših osebnih nastavitev in posodobite vaše šifrirno geslo z vnosom tega gesla v polje 'old log-in password' in vašega trenutnega prijavnega gesla.\n\n",
    "The share will expire on %s." : "Povezava souporabe bo potekla %s.",
    "Cheers!" : "Lep pozdrav!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Pozdravljeni,<br><br> administrator je vklopil šifriranje na strežniku. Vaše datoteke bodo šifrirane z geslom <strong>%s</strong>.<br><br> Prosimo, prijavite se na spletno stran, pojdite na sekcijo 'basic encryption module' vaših osebnih nastavitev in posodobite vaše šifrirno geslo z vnosom tega gesla v polje 'old log-in password' in vašega trenutnega prijavnega gesla.<br><br>",
    "Encrypt the home storage" : "Šifriraj domačo shrambo",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Izbrana možnost omogoči šifriranje vseh datotek, shranjenih v glavni shrambi, sicer so šifrirane le datoteke v zunanjih shrambah.",
    "Enable recovery key" : "Omogoči obnovitveni ključ",
    "Disable recovery key" : "Onemogoči obnovitev gesla",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Obnovitveni ključ je dodatni šifrirni ključ, ki se uporablja pri šifriranju datotek. Omogoča obnovitev uporabnikovih datotek, če uporabnih pozabi svoje geslo za dostop.",
    "Recovery key password" : "Ključ za obnovitev gesla",
    "Repeat recovery key password" : "Ponovi ključ za obnovitev gesla",
    "Change recovery key password:" : "Spremeni ključ za obnovitev gesla:",
    "Old recovery key password" : "Stari ključ za obnovitev gesla",
    "New recovery key password" : "Novi ključ za obnovitev gesla",
    "Repeat new recovery key password" : "Ponovi novi ključ za obnovitev gesla",
    "Change Password" : "Spremeni geslo",
    "Your private key password no longer matches your log-in password." : "Zasebno geslo ni več skladno s prijavnim geslom.",
    "Set your old private key password to your current log-in password:" : "Nastavite star zasebni ključ na trenutno prijavno geslo:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "V kolikor se gesla ne spomnite več, lahko vaše datoteke obnovi le skrbnik sistema.",
    "Old log-in password" : "Staro geslo",
    "Current log-in password" : "Trenutno geslo",
    "Update Private Key Password" : "Posodobi zasebni ključ",
    "Enable password recovery:" : "Omogoči obnovitev gesla:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Nastavitev te možnosti omogoča ponovno pridobitev dostopa do šifriranih datotek, v primeru, da boste geslo pozabili.",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
